summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--NEWS4
-rw-r--r--docs/PORTABLE_SERVICES.md10
-rw-r--r--man/crypttab.xml2
-rw-r--r--man/hostnamectl.xml2
-rw-r--r--man/oomctl.xml2
-rw-r--r--man/portablectl.xml8
-rw-r--r--man/systemd-analyze.xml8
-rw-r--r--man/systemd-getty-generator.xml2
-rw-r--r--man/systemd-measure.xml2
-rw-r--r--man/systemd.path.xml2
-rw-r--r--man/systemd.resource-control.xml2
-rw-r--r--man/systemd.service.xml4
-rw-r--r--man/systemd.time.xml5
-rw-r--r--man/tmpfiles.d.xml4
-rw-r--r--man/udevadm.xml10
-rw-r--r--shell-completion/zsh/_oomctl2
-rw-r--r--shell-completion/zsh/_systemd-analyze4
-rw-r--r--src/basic/meson.build3
-rw-r--r--src/core/timer.c2
-rw-r--r--src/core/unit.h2
-rw-r--r--src/libsystemd-network/sd-dhcp-lease.c2
-rw-r--r--src/network/networkd-wifi.c4
-rw-r--r--src/oom/oomd-manager.c4
-rw-r--r--src/shared/ethtool-util.c2
-rw-r--r--src/shared/format-table.h2
-rw-r--r--src/shared/wifi-util.c4
-rw-r--r--src/systemctl/systemctl-edit.c2
-rw-r--r--src/userdb/userdbctl.c4
-rw-r--r--test/knot-data/knot.conf2
-rwxr-xr-xtest/test-network/systemd-networkd-tests.py6
-rwxr-xr-xtest/units/testsuite-03.sh2
-rw-r--r--tmpfiles.d/systemd-pstore.conf2
32 files changed, 57 insertions, 59 deletions
diff --git a/NEWS b/NEWS
index 22893f51cd..2df2ddb20f 100644
--- a/NEWS
+++ b/NEWS
@@ -2473,9 +2473,9 @@ CHANGES WITH 249:
unit, which will be instantiated using the same instance name.
* A new MemoryAvailable property is available for units. If the unit,
- or the slice(s) it is part of, have a memory limit set via MemoryMax=/
+ or the slices it is part of, have a memory limit set via MemoryMax=/
MemoryHigh=, MemoryAvailable will indicate how much more memory the
- unit can claim before hitting the limit(s).
+ unit can claim before hitting the limits.
* systemd-coredump will now try to stay below the cgroup memory limit
placed on itself or one of the slices it runs under, if the storage
diff --git a/docs/PORTABLE_SERVICES.md b/docs/PORTABLE_SERVICES.md
index 20acbeae03..4f02ddb477 100644
--- a/docs/PORTABLE_SERVICES.md
+++ b/docs/PORTABLE_SERVICES.md
@@ -275,17 +275,17 @@ following must be also be observed:
1. The base/OS image must contain an `os-release file`, either in `/etc/os-release`
or `/usr/lib/os-release`, in the standard format.
-2. The upper extension(s) image(s) must contain an extension-release file in
+2. The upper extension images must contain an extension-release file in
`/usr/lib/extension-release.d/`, with an `ID=` and `SYSEXT_LEVEL=`/`VERSION_ID=`
matching the base image.
3. The base/OS image does not need to have any unit files.
-4. The upper extension(s) image(s) must at least contain one matching unit file each,
- with the right name prefix and suffix (see above).
+4. The upper extension images must contain at least one matching unit file
+ each, with the right name prefix and suffix (see above).
-5. As with the base/OS image, the upper extension(s) image(s) must be a plain
- sub-directory, a btrfs subvolume or a raw disk image.
+5. As with the base/OS image, each upper extension image must be a plain
+ sub-directory, btrfs subvolume, or a raw disk image.
```
# portablectl attach --extension foobar_0.7.23.raw debian-runtime_11.1.raw foobar
diff --git a/man/crypttab.xml b/man/crypttab.xml
index 363691a007..cbbb8ab2a9 100644
--- a/man/crypttab.xml
+++ b/man/crypttab.xml
@@ -94,7 +94,7 @@
<orderedlist>
<listitem><para>Most prominently, the user may be queried interactively during volume activation
- (i.e. typically at boot), asking them to type in the necessary passphrase(s).</para></listitem>
+ (i.e. typically at boot), asking them to type in the necessary passphrases.</para></listitem>
<listitem><para>The (unencrypted) key may be read from a file on disk, possibly on removable media. The third field
of each line encodes the location, for details see above.</para></listitem>
diff --git a/man/hostnamectl.xml b/man/hostnamectl.xml
index 3697bbb474..6933c68e38 100644
--- a/man/hostnamectl.xml
+++ b/man/hostnamectl.xml
@@ -175,7 +175,7 @@
<listitem><para>If <command>status</command> is invoked (or no explicit command is given) and one of these
switches is specified, <command>hostnamectl</command> will print out just this selected hostname.</para>
- <para>If used with <command>set-hostname</command>, only the selected hostname(s) will be updated. When more
+ <para>If used with <command>set-hostname</command>, only the selected hostnames will be updated. When more
than one of these switches are specified, all the specified hostnames will be updated. </para></listitem>
</varlistentry>
diff --git a/man/oomctl.xml b/man/oomctl.xml
index b5e8a44282..950e79df13 100644
--- a/man/oomctl.xml
+++ b/man/oomctl.xml
@@ -48,7 +48,7 @@
<varlistentry>
<term><command>dump</command></term>
- <listitem><para>Show the current state of the cgroup(s) and system context(s) stored by
+ <listitem><para>Show the current state of the cgroups and system contexts stored by
<command>systemd-oomd</command>.</para></listitem>
</varlistentry>
diff --git a/man/portablectl.xml b/man/portablectl.xml
index deb7842d1f..963361e28c 100644
--- a/man/portablectl.xml
+++ b/man/portablectl.xml
@@ -135,7 +135,7 @@
when <option>--no-reload</option> is specified (see below). This ensures that the new units made available to
the service manager are seen by it.</para>
- <para>If <option>--now</option> and/or <option>--enable</option> are passed, the portable service(s) are
+ <para>If <option>--now</option> and/or <option>--enable</option> are passed, the portable services are
immediately started (blocking operation unless <option>--no-block</option> is passed) and/or enabled after
attaching the image.</para>
</listitem>
@@ -151,7 +151,7 @@
files. This is a convenience feature to allow all arguments passed as <command>attach</command> also to
<command>detach</command>.</para></listitem>
- <para>If <option>--now</option> and/or <option>--enable</option> are passed, the portable service(s) are
+ <para>If <option>--now</option> and/or <option>--enable</option> are passed, the portable services are
immediately stopped (blocking operation) and/or disabled before detaching the image. Prefix(es) are also accepted,
to be used in case the unit names do not match the image name as described in the <command>attach</command>.</para>
</varlistentry>
@@ -165,7 +165,7 @@
character has to match. If the new image doesn't exist, the existing one will not be detached. The parameters
follow the same syntax as the <command>attach</command> command.</para></listitem>
- <para>If <option>--now</option> and/or <option>--enable</option> are passed, the portable service(s) are
+ <para>If <option>--now</option> and/or <option>--enable</option> are passed, the portable services are
immediately stopped if removed, started and/or enabled if added, or restarted if updated. Prefixes are also
accepted, in the same way as described in the <command>attach</command> case.</para>
</varlistentry>
@@ -362,7 +362,7 @@
<citerefentry><refentrytitle>systemd.exec</refentrytitle><manvolnum>5</manvolnum></citerefentry>
for the <varname>ExtensionImages=</varname> directive and for the
<citerefentry><refentrytitle>systemd-sysext</refentrytitle><manvolnum>8</manvolnum></citerefentry> tool.
- The image(s) must contain an <filename>extension-release</filename> file with metadata that matches
+ The images must contain an <filename>extension-release</filename> file with metadata that matches
what is defined in the <filename>os-release</filename> of <replaceable>IMAGE</replaceable>. See:
<citerefentry><refentrytitle>os-release</refentrytitle><manvolnum>5</manvolnum></citerefentry>.
Images can be block images, btrfs subvolumes or directories. For more information on portable
diff --git a/man/systemd-analyze.xml b/man/systemd-analyze.xml
index cce08fa121..0d91cdd7d0 100644
--- a/man/systemd-analyze.xml
+++ b/man/systemd-analyze.xml
@@ -742,7 +742,7 @@ $ systemd-analyze verify /tmp/source:alias.service
<refsect2>
<title><command>systemd-analyze inspect-elf <replaceable>FILE</replaceable>...</command></title>
- <para>This command will load the specified file(s), and if they are ELF objects (executables,
+ <para>This command will load the specified files, and if they are ELF objects (executables,
libraries, core files, etc.) it will parse the embedded packaging metadata, if any, and print
it in a table or json format. See the <ulink url="https://systemd.io/COREDUMP_PACKAGE_METADATA/">
Packaging Metadata</ulink> documentation for more information.</para>
@@ -902,7 +902,7 @@ $ systemd-analyze verify /tmp/source:alias.service
<term><option>--offline=<replaceable>BOOL</replaceable></option></term>
<listitem><para>With <command>security</command>, perform an offline security review
- of the specified unit file(s), i.e. does not have to rely on PID 1 to acquire security
+ of the specified unit files, i.e. does not have to rely on PID 1 to acquire security
information for the files like the <command>security</command> verb when used by itself does.
This means that <option>--offline=</option> can be used with <option>--root=</option> and
<option>--image=</option> as well. If a unit's overall exposure level is above that set by
@@ -914,7 +914,7 @@ $ systemd-analyze verify /tmp/source:alias.service
<term><option>--profile=<replaceable>PATH</replaceable></option></term>
<listitem><para>With <command>security</command> <option>--offline=</option>, takes into
- consideration the specified portable profile when assessing the unit(s) settings.
+ consideration the specified portable profile when assessing unit settings.
The profile can be passed by name, in which case the well-known system locations will
be searched, or it can be the full path to a specific drop-in file.</para></listitem>
</varlistentry>
@@ -923,7 +923,7 @@ $ systemd-analyze verify /tmp/source:alias.service
<term><option>--threshold=<replaceable>NUMBER</replaceable></option></term>
<listitem><para>With <command>security</command>, allow the user to set a custom value
- to compare the overall exposure level with, for the specified unit file(s). If a unit's
+ to compare the overall exposure level with, for the specified unit files. If a unit's
overall exposure level, is greater than that set by the user, <command>security</command>
will return an error. <option>--threshold=</option> can be used with <option>--offline=</option>
as well and its default value is 100.</para></listitem>
diff --git a/man/systemd-getty-generator.xml b/man/systemd-getty-generator.xml
index 038613d829..def38520df 100644
--- a/man/systemd-getty-generator.xml
+++ b/man/systemd-getty-generator.xml
@@ -29,7 +29,7 @@
<title>Description</title>
<para><filename>systemd-getty-generator</filename> is a generator that automatically instantiates
- <filename>serial-getty@.service</filename> on the kernel console(s), if they can function as ttys and are
+ <filename>serial-getty@.service</filename> on the kernel consoles, if they can function as ttys and are
not provided by the virtual console subsystem. It will also instantiate
<filename>serial-getty@.service</filename> instances for virtualizer consoles, if execution in a
virtualized environment is detected. If execution in a container environment is detected, it will instead
diff --git a/man/systemd-measure.xml b/man/systemd-measure.xml
index 793821ab0a..46fc979654 100644
--- a/man/systemd-measure.xml
+++ b/man/systemd-measure.xml
@@ -162,7 +162,7 @@
<varlistentry>
<term><option>--phase=</option><replaceable>PHASE</replaceable></term>
- <listitem><para>Controls which boot phase(s) to calculate expected PCR 11 values for. This takes a
+ <listitem><para>Controls which boot phases to calculate expected PCR 11 values for. This takes a
series of colon-separated strings that encode boot "paths" for entering a specific phase of the boot
process. Each of the specified strings is measured by the
<filename>systemd-pcrphase-initrd.service</filename> and
diff --git a/man/systemd.path.xml b/man/systemd.path.xml
index f143208cb4..f8748bf700 100644
--- a/man/systemd.path.xml
+++ b/man/systemd.path.xml
@@ -198,7 +198,7 @@
details on the various time units understood. The <varname>TriggerLimitBurst=</varname> setting takes
a positive integer value and specifies the number of permitted activations per time interval, and
defaults to 200. Set either to 0 to disable any form of trigger rate limiting. If the limit is hit,
- the unit is placed into a failure mode, and will not watch the path(s) anymore until restarted. Note
+ the unit is placed into a failure mode, and will not watch the paths anymore until restarted. Note
that this limit is enforced before the service activation is enqueued.</para></listitem>
</varlistentry>
</variablelist>
diff --git a/man/systemd.resource-control.xml b/man/systemd.resource-control.xml
index 2b1c20b96e..2a0e40a17d 100644
--- a/man/systemd.resource-control.xml
+++ b/man/systemd.resource-control.xml
@@ -852,7 +852,7 @@ RestrictNetworkInterfaces=~eth1</programlisting>
<para>Control access to specific device nodes by the executed processes. Takes two space-separated
strings: a device node specifier followed by a combination of <constant>r</constant>,
<constant>w</constant>, <constant>m</constant> to control <emphasis>r</emphasis>eading,
- <emphasis>w</emphasis>riting, or creation of the specific device node(s) by the unit
+ <emphasis>w</emphasis>riting, or creation of the specific device nodes by the unit
(<emphasis>m</emphasis>knod), respectively. This functionality is implemented using eBPF
filtering.</para>
diff --git a/man/systemd.service.xml b/man/systemd.service.xml
index 98c8bf8c6d..8d8dd77689 100644
--- a/man/systemd.service.xml
+++ b/man/systemd.service.xml
@@ -467,7 +467,7 @@
<varlistentry>
<term><varname>ExecCondition=</varname></term>
- <listitem><para>Optional commands that are executed before the command(s) in <varname>ExecStartPre=</varname>.
+ <listitem><para>Optional commands that are executed before the commands in <varname>ExecStartPre=</varname>.
Syntax is the same as for <varname>ExecStart=</varname>, except that multiple command lines are allowed and the
commands are executed one after the other, serially.</para>
@@ -476,7 +476,7 @@
commands are skipped and the unit is <emphasis>not</emphasis> marked as failed. However, if an
<varname>ExecCondition=</varname> command exits with 255 or abnormally (e.g. timeout, killed by a
signal, etc.), the unit will be considered failed (and remaining commands will be skipped). Exit code of 0 or
- those matching <varname>SuccessExitStatus=</varname> will continue execution to the next command(s).</para>
+ those matching <varname>SuccessExitStatus=</varname> will continue execution to the next commands.</para>
<para>The same recommendations about not running long-running processes in <varname>ExecStartPre=</varname>
also applies to <varname>ExecCondition=</varname>. <varname>ExecCondition=</varname> will also run the commands
diff --git a/man/systemd.time.xml b/man/systemd.time.xml
index a759707fec..643ff7d78f 100644
--- a/man/systemd.time.xml
+++ b/man/systemd.time.xml
@@ -220,9 +220,8 @@ tomorrow Pacific/Auckland → Thu 2012-11-23 19:00:00
times starting with the start value, and continuing with all multiples of the repetition value relative
to the start value, ending at the end value the latest.</para>
- <para>A date specification may use <literal>~</literal> to indicate the
- last day(s) in a month. For example, <literal>*-02~03</literal> means
- "the third last day in February," and <literal>Mon *-05~07/1</literal>
+ <para>A date specification may use <literal>~</literal> to indicate the last day in a month. For example,
+ <literal>*-02~03</literal> means "the third last day in February," and <literal>Mon *-05~07/1</literal>
means "the last Monday in May."</para>
<para>The seconds component may contain decimal fractions both in
diff --git a/man/tmpfiles.d.xml b/man/tmpfiles.d.xml
index 4ede01c82d..bd3bc33ab4 100644
--- a/man/tmpfiles.d.xml
+++ b/man/tmpfiles.d.xml
@@ -418,8 +418,8 @@ L /tmp/foobar - - - - /dev/null</programlisting>
place of normal path names.</para>
<para>The format of the argument field is <varname>[+-=][aAcCdDeijPsStTu]</varname>. The prefix
- <varname>+</varname> (the default one) causes the attribute(s) to be added; <varname>-</varname>
- causes the attribute(s) to be removed; <varname>=</varname> causes the attributes to be set exactly
+ <varname>+</varname> (the default one) causes the attributes to be added; <varname>-</varname>
+ causes the attributes to be removed; <varname>=</varname> causes the attributes to be set exactly
as the following letters. The letters <literal>aAcCdDeijPsStTu</literal> select the new attributes
for the files, see <citerefentry project='man-pages'><refentrytitle>chattr</refentrytitle>
<manvolnum>1</manvolnum></citerefentry> for further information.
diff --git a/man/udevadm.xml b/man/udevadm.xml
index 47556ee9b3..ee0658dc14 100644
--- a/man/udevadm.xml
+++ b/man/udevadm.xml
@@ -800,9 +800,9 @@
</title>
- <para><command>udevadm lock</command> takes an (advisory) exclusive lock(s) on a block device (or
- multiple thereof), as per <ulink url="https://systemd.io/BLOCK_DEVICE_LOCKING">Locking Block Device
- Access</ulink> and invokes a program with the lock(s) taken. When the invoked program exits the lock(s)
+ <para><command>udevadm lock</command> takes an (advisory) exclusive lock on a block device (or all
+ specified devices), as per <ulink url="https://systemd.io/BLOCK_DEVICE_LOCKING">Locking Block Device
+ Access</ulink> and invokes a program with the locks taken. When the invoked program exits the locks
are automatically released and its return value is propagated as exit code of <command>udevadm
lock</command>.</para>
@@ -861,8 +861,8 @@
<term><option>--print</option></term>
<term><option>-p</option></term>
- <listitem><para>Instead of locking the specified device(s) and executing a command, just print the
- device path(s) that would be locked, and execute no command. This command is useful to determine
+ <listitem><para>Instead of locking the specified devices and executing a command, just print the
+ device paths that would be locked, and execute no command. This command is useful to determine
the "whole" block device in case a partition block device is specified. The devices will be sorted
by their device node major number as primary ordering key and the minor number as secondary
ordering key (i.e. they are shown in the order they'd be locked). Note that the number of lines
diff --git a/shell-completion/zsh/_oomctl b/shell-completion/zsh/_oomctl
index f956340b7e..18e1938ab9 100644
--- a/shell-completion/zsh/_oomctl
+++ b/shell-completion/zsh/_oomctl
@@ -5,7 +5,7 @@
{
local -a _oomctl_cmds
_oomctl_cmds=(
- "dump:Show the current state of the cgroup(s) and system context(s)"
+ "dump:Show the current state of cgroups and system contexts"
"help:Prints a short help text and exits."
)
if (( CURRENT == 1 )); then
diff --git a/shell-completion/zsh/_systemd-analyze b/shell-completion/zsh/_systemd-analyze
index 2ce8a3a088..e305995cef 100644
--- a/shell-completion/zsh/_systemd-analyze
+++ b/shell-completion/zsh/_systemd-analyze
@@ -96,9 +96,9 @@ _arguments \
'--recursive-errors=[When verifying a unit, control dependency verification]:MODE' \
'--offline=[Perform a security review of the specified unit files]:BOOL:(yes no)' \
'--threshold=[Set a value to compare the overall security exposure level with]: NUMBER' \
- '--security-policy=[Allow user to use customized requirements to compare unit file(s) against]: PATH' \
+ '--security-policy=[Use customized requirements to compare unit files against]: PATH' \
'--json=[Generate a JSON output of the security analysis table]:MODE:(pretty short off)' \
- '--profile=[Include the specified profile in the security review of the unit(s)]: PATH' \
+ '--profile=[Include the specified profile in the security review of units]: PATH' \
'--no-pager[Do not pipe output into a pager]' \
'--man=[Do (not) check for existence of man pages]:BOOL:(yes no)' \
'--generators=[Do (not) run unit generators]:BOOL:(yes no)' \
diff --git a/src/basic/meson.build b/src/basic/meson.build
index 6187b90732..bfe52d5879 100644
--- a/src/basic/meson.build
+++ b/src/basic/meson.build
@@ -389,8 +389,7 @@ filesystem_includes = ['linux/magic.h',
check_filesystems = find_program('check-filesystems.sh')
r = run_command([check_filesystems, cpp, files('filesystems-gperf.gperf')] + filesystem_includes, check: false)
if r.returncode() != 0
- error('found unknown filesystem(s) defined in kernel headers:\n\n' + r.stdout())
- r.stdout()
+ error('Unknown filesystems defined in kernel headers:\n\n' + r.stdout())
endif
filesystems_gperf_h = custom_target(
diff --git a/src/core/timer.c b/src/core/timer.c
index b89d593b75..cfc20fb613 100644
--- a/src/core/timer.c
+++ b/src/core/timer.c
@@ -821,7 +821,7 @@ static void timer_time_change(Unit *u) {
/* If we appear to have triggered in the future, the system clock must
* have been set backwards. So let's rewind our own clock and allow
- * the future trigger(s) to happen again :). Exactly the same as when
+ * the future triggers to happen again :). Exactly the same as when
* you start a timer unit with Persistent=yes. */
ts = now(CLOCK_REALTIME);
if (t->last_trigger.realtime > ts)
diff --git a/src/core/unit.h b/src/core/unit.h
index b34c59c3eb..3bc7de3d1c 100644
--- a/src/core/unit.h
+++ b/src/core/unit.h
@@ -772,7 +772,7 @@ typedef struct UnitVTable {
/* True if queued jobs of this type should be GC'ed if no other job needs them anymore */
bool gc_jobs;
- /* True if systemd-oomd can monitor and act on this unit's recursive children's cgroup(s) */
+ /* True if systemd-oomd can monitor and act on this unit's recursive children's cgroups */
bool can_set_managed_oom;
} UnitVTable;
diff --git a/src/libsystemd-network/sd-dhcp-lease.c b/src/libsystemd-network/sd-dhcp-lease.c
index d84a356663..d9db35fbac 100644
--- a/src/libsystemd-network/sd-dhcp-lease.c
+++ b/src/libsystemd-network/sd-dhcp-lease.c
@@ -608,7 +608,7 @@ static int lease_parse_6rd(sd_dhcp_lease *lease, const uint8_t *option, size_t l
memcpy(&prefix, option + 2, sizeof(struct in6_addr));
(void) in6_addr_mask(&prefix, prefixlen);
- /* 6rdBRIPv4Address: One or more IPv4 addresses of the 6rd Border Relay(s) for a given 6rd domain. */
+ /* 6rdBRIPv4Address: One or more IPv4 addresses of the 6rd Border Relays for a given 6rd domain. */
n_br_addresses = (len - 2 - sizeof(struct in6_addr)) / sizeof(struct in_addr);
br_addresses = newdup(struct in_addr, option + 2 + sizeof(struct in6_addr), n_br_addresses);
if (!br_addresses)
diff --git a/src/network/networkd-wifi.c b/src/network/networkd-wifi.c
index 13d6734a02..4bf798a9eb 100644
--- a/src/network/networkd-wifi.c
+++ b/src/network/networkd-wifi.c
@@ -123,10 +123,10 @@ int manager_genl_process_nl80211_config(sd_netlink *genl, sd_netlink_message *me
}
if (r >= 0) {
if (len == 0) {
- log_link_debug(link, "nl80211: received SSID has zero length, ignoring the received SSID: %m");
+ log_link_debug(link, "nl80211: received SSID has zero length, ignoring it: %m");
ssid = mfree(ssid);
} else if (strlen_ptr(ssid) != len) {
- log_link_debug(link, "nl80211: received SSID contains NUL character(s), ignoring the received SSID.");
+ log_link_debug(link, "nl80211: received SSID contains NUL characters, ignoring it.");
ssid = mfree(ssid);
}
}
diff --git a/src/oom/oomd-manager.c b/src/oom/oomd-manager.c
index 51bec79ba8..4a43807b87 100644
--- a/src/oom/oomd-manager.c
+++ b/src/oom/oomd-manager.c
@@ -403,7 +403,7 @@ static int monitor_swap_contexts_handler(sd_event_source *s, uint64_t usec, void
if (r == -ENOMEM)
return log_oom();
if (r < 0)
- log_notice_errno(r, "Failed to kill any cgroup(s) based on swap: %m");
+ log_notice_errno(r, "Failed to kill any cgroups based on swap: %m");
else {
if (selected && r > 0) {
log_notice("Killed %s due to memory used (%"PRIu64") / total (%"PRIu64") and "
@@ -520,7 +520,7 @@ static int monitor_memory_pressure_contexts_handler(sd_event_source *s, uint64_t
if (r == -ENOMEM)
return log_oom();
if (r < 0)
- log_notice_errno(r, "Failed to kill any cgroup(s) under %s based on pressure: %m", t->path);
+ log_notice_errno(r, "Failed to kill any cgroups under %s based on pressure: %m", t->path);
else {
/* Don't act on all the high pressure cgroups at once; return as soon as we kill one.
* If r == 0 then it means there were not eligible candidates, the candidate cgroup
diff --git a/src/shared/ethtool-util.c b/src/shared/ethtool-util.c
index bc51e69f85..e39b2f754b 100644
--- a/src/shared/ethtool-util.c
+++ b/src/shared/ethtool-util.c
@@ -449,7 +449,7 @@ int ethtool_set_wol(
_cleanup_free_ char *str = NULL;
(void) wol_options_to_string_alloc(wolopts & ~ecmd.supported, &str);
- log_debug("Network interface %s does not support requested Wake on LAN option(s) \"%s\", ignoring.",
+ log_debug("Network interface %s does not support requested Wake on LAN options \"%s\", ignoring.",
ifname, strna(str));
wolopts &= ecmd.supported;
diff --git a/src/shared/format-table.h b/src/shared/format-table.h
index 3a7c2774b6..c88a060dbe 100644
--- a/src/shared/format-table.h
+++ b/src/shared/format-table.h
@@ -142,7 +142,7 @@ int table_print_with_pager(Table *t, JsonFormatFlags json_format_flags, PagerFla
int table_set_json_field_name(Table *t, size_t column, const char *name);
#define table_log_add_error(r) \
- log_error_errno(r, "Failed to add cell(s) to table: %m")
+ log_error_errno(r, "Failed to add cells to table: %m")
#define table_log_print_error(r) \
log_error_errno(r, "Failed to print table: %m")
diff --git a/src/shared/wifi-util.c b/src/shared/wifi-util.c
index d32bb5d704..d4e6dcac07 100644
--- a/src/shared/wifi-util.c
+++ b/src/shared/wifi-util.c
@@ -60,10 +60,10 @@ int wifi_get_interface(sd_netlink *genl, int ifindex, enum nl80211_iftype *ret_i
return log_debug_errno(r, "Failed to get NL80211_ATTR_SSID attribute: %m");
if (r >= 0) {
if (len == 0) {
- log_debug("SSID has zero length, ignoring the received SSID.");
+ log_debug("SSID has zero length, ignoring it.");
ssid = mfree(ssid);
} else if (strlen_ptr(ssid) != len) {
- log_debug("SSID contains NUL character(s), ignoring the received SSID.");
+ log_debug("SSID contains NUL characters, ignoring it.");
ssid = mfree(ssid);
}
}
diff --git a/src/systemctl/systemctl-edit.c b/src/systemctl/systemctl-edit.c
index a363d7a494..fe47f73d4a 100644
--- a/src/systemctl/systemctl-edit.c
+++ b/src/systemctl/systemctl-edit.c
@@ -367,7 +367,7 @@ static int run_editor(char **paths) {
}
}
- log_error("Cannot edit unit(s), no editor available. Please set either $SYSTEMD_EDITOR, $EDITOR or $VISUAL.");
+ log_error("Cannot edit units, no editor available. Please set either $SYSTEMD_EDITOR, $EDITOR or $VISUAL.");
_exit(EXIT_FAILURE);
}
diff --git a/src/userdb/userdbctl.c b/src/userdb/userdbctl.c
index 6afec0cda2..63b0c4dde1 100644
--- a/src/userdb/userdbctl.c
+++ b/src/userdb/userdbctl.c
@@ -1065,8 +1065,8 @@ static int help(int argc, char *argv[], void *userdata) {
"\nCommands:\n"
" user [USER…] Inspect user\n"
" group [GROUP…] Inspect group\n"
- " users-in-group [GROUP…] Show users that are members of specified group(s)\n"
- " groups-of-user [USER…] Show groups the specified user(s) is a member of\n"
+ " users-in-group [GROUP…] Show users that are members of specified groups\n"
+ " groups-of-user [USER…] Show groups the specified users are members of\n"
" services Show enabled database services\n"
" ssh-authorized-keys USER Show SSH authorized keys for user\n"
"\nOptions:\n"
diff --git a/test/knot-data/knot.conf b/test/knot-data/knot.conf
index a6f2f45b24..e3de69d0f4 100644
--- a/test/knot-data/knot.conf
+++ b/test/knot-data/knot.conf
@@ -85,7 +85,7 @@ template:
zone:
# Create our own DNSSEC-aware root zone, so we can test the whole chain of
# trust. This needs a ZSK/KSK keypair to be generated before running knot +
- # adding the respective key(s) to resolved's trust anchor store (see the
+ # adding the respective keys to resolved's trust anchor store (see the
# test script for the setup steps).
- domain: .
dnssec-policy: manual
diff --git a/test/units/testsuite-03.sh b/test/units/testsuite-03.sh
index 4b3b409760..1d4bf3aaaa 100755
--- a/test/units/testsuite-03.sh
+++ b/test/units/testsuite-03.sh
@@ -72,7 +72,7 @@ systemctl stop --job-mode=replace-irreversibly unstoppable.service
# Shutdown of the container/VM will hang if not.
systemctl start unstoppable.service
-# Test waiting for a started unit(s) to terminate again
+# Test waiting for a started units to terminate again
cat <<EOF >/run/systemd/system/wait2.service
[Unit]
Description=Wait for 2 seconds
diff --git a/tmpfiles.d/systemd-pstore.conf b/tmpfiles.d/systemd-pstore.conf
index e6540b5de4..9425169c75 100644
--- a/tmpfiles.d/systemd-pstore.conf
+++ b/tmpfiles.d/systemd-pstore.conf
@@ -21,7 +21,7 @@
# upon a normal shutdown (shutdown, reboot, halt).
#
# To configure the kernel parameters, uncomment the appropriate
-# line(s) below. The value written is either 'Y' to enable the
+# lines below. The value written is either 'Y' to enable the
# kernel parameter, or 'N' to disable the kernel parameter.
#
# After making a change to this file, do:
diff --git a/test/test-network/systemd-networkd-tests.py b/test/test-network/systemd-networkd-tests.py
index 2f638d158a..2f7614428c 100755
--- a/test/test-network/systemd-networkd-tests.py
+++ b/test/test-network/systemd-networkd-tests.py
@@ -827,7 +827,7 @@ class Utilities():
return False
def wait_online(self, links_with_operstate, timeout='20s', bool_any=False, ipv4=False, ipv6=False, setup_state='configured', setup_timeout=5):
"""Wait for the link(s) to reach the specified operstate and/or setup state.
This is similar to wait_operstate() but can be used for multiple links,
and it also calls systemd-networkd-wait-online to wait for the given operstate.
@@ -843,10 +843,10 @@ class Utilities():
Set 'ipv4' or 'ipv6' to True to wait for IPv4 address or IPv6 address, respectively, of each of the given links.
This is applied only for the operational state 'degraded' or above.
- Note that this function waits for the link(s) to reach *or exceed* the given operstate.
+ Note that this function waits for the links to reach *or exceed* the given operstate.
However, the setup_state, if specified, must be matched *exactly*.
- This returns if the link(s) reached the requested operstate/setup_state; otherwise it
+ This returns if the links reached the requested operstate/setup_state; otherwise it
raises CalledProcessError or fails test assertion.
"""
args = wait_online_cmd + [f'--timeout={timeout}'] + [f'--interface={link}' for link in links_with_operstate]
@@ -827,7 +827,7 @@ class Utilities():
return False
def wait_online(self, links_with_operstate, timeout='20s', bool_any=False, ipv4=False, ipv6=False, setup_state='configured', setup_timeout=5):
- """Wait for the link(s) to reach the specified operstate and/or setup state.
+ """Wait for the links to reach the specified operstate and/or setup state.
This is similar to wait_operstate() but can be used for multiple links,
and it also calls systemd-networkd-wait-online to wait for the given operstate.